Name: libassuan
Version: 2.5.3
Release: 1
License: GPL-3.0-or-later
Summary: Implementation of Assuan protocol
Url: https://gnupg.org/software/libassuan/index.html

Source0: https://gnupg.org/ftp/gcrypt/libassuan/libassuan-%{version}.tar.bz2

BuildRequires: libtool
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libgpg-error-devel

%description
Libassuan is a small library implementing the so-called Assuan protocol. This
protocol is used for IPC between most newer GnuPG components. Both, server and
client side functions are provided.

In an ideal world, Assuan is irrelevant. Assuan's primary use is to allow a
client to interact with a non-persistent server. Using Assuan, this is
accomplished by forking a subprocess and communicating with it via, for example
a pipe or unix domain socket. This method is neither elegant nor efficient
especially when there is a lot of data spread across several transactions: not
only is there a penalty for an increased number of context switches, but also a
significant amount of data is memcpy-ed from the client to a file descriptor
and from the file descriptor to the server. Despite these and other
disadvantages, this type of client/server communication can be useful: the
client is completely separate from the server; they are in different address
spaces. This is especially important in situations where the server must have a
known degree of reliability and data must be protected: as the Assuan protocol
is well defined and clients cannot corrupt the servers' address space, auditing
become much easier.

Assuan was developed for use by the GNU Privacy Guard, GnuPG, to prevent
potentially buggy clients from unwittingly corrupting sensitive transactions or
compromising data such as a secret key. Assuan permits the servers, which do
the actual work, e.g. encryption and decryption of data using a secret key, to
be developed independently of the user interfaces, e.g. mail clients and other
encryption front ends. Like a shared library, the interface is well defined and
any number of front ends can use it; however, unlike a shared library, the
client cannot see or touch the server's data. As with any modular system,
Assuan helps keep the servers small and understandable, and helps to make code
more understandable and less error prone.

Assuan is not, however, limited to use with GnuPG servers and clients: it was
design to be flexible enough to meet the demands of almost any transaction
based environment with non-persistent servers.


%package devel
Summary: libassuan development files

Requires: libassuan0 = %{version}-%{release}

%description devel
%summary


%package -n libassuan0
Summary: libassuan library

%description -n libassuan0
%summary


%prep

%setup -q -n %{name}-%{version}


%build

autoreconf -fi

%configure \
  ac_cv_func_getpeereid="no" \
  LDFLAGS="-Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
  --enable-shared \
  --disable-static \
  --with-aix-soname=svr4

%make_build


%install

%make_install

# don't ship .la file
rm %{buildroot}/%{_libdir}/libassuan.la


%files devel
%defattr(-, qsys, *none)

%{_bindir}/libassuan-config

%{_includedir}/assuan.h

%{_libdir}/libassuan.so
%{_libdir}/pkgconfig/libassuan.pc

%{_datadir}/aclocal/libassuan.m4

%{_infodir}/assuan.info


%files -n libassuan0
%defattr(-, qsys, *none)

%{_libdir}/libassuan.so.0


%changelog
* Mon Feb 10 2020 Mark Irish <mirish@ibm.com> - 2.5.3
- Intial package
